@@ -309,11 +309,15 @@ def split_conflict_spans(entities, tokens, text):
 import regex as re
 
 def detect_language(text):
+    if re.compile('\p{Han}{2,}').match(text):
+        return 'cn'
+
     cn = 0
     en = 0
+
     for ch in text:
         if re.compile('\p{Letter}').match(ch):
-            if re.compile('\p{Han}').fullmatch(ch):
+            if re.compile('\p{Han}').match(ch):
                 cn += 2
             else:
                 en += 1    
